#### SMARTY DISCLAIMER: Subject to the terms of the associated license agreement, this software is freely available for your use. This software is FREE, AS IN PUPPIES, and is a gift. Enjoy your new responsibility. This means that while we may consider enhancement requests, we may or may not choose to entertain requests at our sole and absolute discretion.

# SmartyStreets Python SDK

The official client libraries for accessing SmartyStreets APIs from Python 2.7 and 3.5

You may have noticed this page is curiously sparse. Don't panic, there's [documentation](https://smartystreets.com/docs/sdk/python) and [examples](examples).

[Apache 2.0 License](LICENSE.txt)

---

[![asciicast](https://asciinema.org/a/122131.png)](https://asciinema.org/a/122131)

---
